You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by hi...@apache.org on 2016/09/13 23:02:15 UTC

[29/51] [partial] incubator-geode git commit: GEODE-37 changed import to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventFilter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventFilter.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventFilter.java
index 2ed3ea6..b8620e2 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventFilter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventFilter.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
-import com.gemstone.gemfire.cache.CacheCallback;
+import org.apache.geode.cache.CacheCallback;
 
 /**
  * Callback for users to filter out events before dispatching to remote

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventSubstitutionFilter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventSubstitutionFilter.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventSubstitutionFilter.java
index 7e37310..0ec894a 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventSubstitutionFilter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayEventSubstitutionFilter.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
-import com.gemstone.gemfire.cache.CacheCallback;
-import com.gemstone.gemfire.cache.EntryEvent;
+import org.apache.geode.cache.CacheCallback;
+import org.apache.geode.cache.EntryEvent;
 
 /**
  * Interface <code>GatewayEventSubstitutionFilter</code> provides a way to

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayQueueEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayQueueEvent.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayQueueEvent.java
index 07d92c9..8d9a8aa 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayQueueEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayQueueEvent.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
-import com.gemstone.gemfire.cache.Operation;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventListener;
+import org.apache.geode.cache.Operation;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.asyncqueue.AsyncEventListener;
 
 /**
  * Represents <code>Cache</code> events going through 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiver.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiver.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiver.java
index a80fbd4..55021d1 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiver.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiver.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
-import com.gemstone.gemfire.cache.server.CacheServer;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
+import org.apache.geode.cache.server.CacheServer;
+import org.apache.geode.distributed.internal.DistributionConfig;
 
 import java.io.IOException;
 import java.util.List;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiverFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiverFactory.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiverFactory.java
index 38e0316..4a6a7a8 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiverFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayReceiverFactory.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
 /**
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySender.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySender.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySender.java
index 04dc248..0b4c113 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySender.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySender.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.DistributionConfig;
 
 import java.util.List;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySenderFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySenderFactory.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySenderFactory.java
index 4ecf8ae..ec38f5c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySenderFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewaySenderFactory.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
-import com.gemstone.gemfire.cache.wan.GatewaySender.OrderPolicy;
+import org.apache.geode.cache.wan.GatewaySender.OrderPolicy;
 
 /**
  * Factory to create SerialGatewaySender

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayTransportFilter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayTransportFilter.java b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayTransportFilter.java
index db76ba5..16dee89 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayTransportFilter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/wan/GatewayTransportFilter.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.wan;
+package org.apache.geode.cache.wan;
 
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import com.gemstone.gemfire.cache.CacheCallback;
+import org.apache.geode.cache.CacheCallback;
 
 public interface GatewayTransportFilter extends CacheCallback {
   public InputStream  getInputStream(InputStream stream);

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/compression/CompressionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/compression/CompressionException.java b/geode-core/src/main/java/org/apache/geode/compression/CompressionException.java
index 0e3c26b..ebcc9c7 100644
--- a/geode-core/src/main/java/org/apache/geode/compression/CompressionException.java
+++ b/geode-core/src/main/java/org/apache/geode/compression/CompressionException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.compression;
+package org.apache.geode.compression;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * Wraps specific compression errors for {@link Compressor

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/compression/Compressor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/compression/Compressor.java b/geode-core/src/main/java/org/apache/geode/compression/Compressor.java
index ee06220..b50839e 100644
--- a/geode-core/src/main/java/org/apache/geode/compression/Compressor.java
+++ b/geode-core/src/main/java/org/apache/geode/compression/Compressor.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.compression;
+package org.apache.geode.compression;
 
 /**
  * Interface for a compression codec.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/compression/SnappyCompressor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/compression/SnappyCompressor.java b/geode-core/src/main/java/org/apache/geode/compression/SnappyCompressor.java
index 63ec29d..0c601d2 100644
--- a/geode-core/src/main/java/org/apache/geode/compression/SnappyCompressor.java
+++ b/geode-core/src/main/java/org/apache/geode/compression/SnappyCompressor.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.compression;
+package org.apache.geode.compression;
 
 import java.io.Serializable;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/AbstractLauncher.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/AbstractLauncher.java b/geode-core/src/main/java/org/apache/geode/distributed/AbstractLauncher.java
index 77e360b..110721f 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/AbstractLauncher.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/AbstractLauncher.java
@@ -15,23 +15,23 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
-
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.distributed.internal.unsafe.RegisterSignalHandlerSupport;
-import com.gemstone.gemfire.internal.AvailablePort;
-import com.gemstone.gemfire.internal.GemFireVersion;
-import com.gemstone.gemfire.internal.OSProcess;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.lang.ClassUtils;
-import com.gemstone.gemfire.internal.lang.ObjectUtils;
-import com.gemstone.gemfire.internal.lang.StringUtils;
-import com.gemstone.gemfire.internal.lang.SystemUtils;
-import com.gemstone.gemfire.internal.process.PidUnavailableException;
-import com.gemstone.gemfire.internal.process.ProcessUtils;
-import com.gemstone.gemfire.internal.util.SunAPINotFoundException;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonObject;
+package org.apache.geode.distributed;
+
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.distributed.internal.unsafe.RegisterSignalHandlerSupport;
+import org.apache.geode.internal.AvailablePort;
+import org.apache.geode.internal.GemFireVersion;
+import org.apache.geode.internal.OSProcess;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.lang.ClassUtils;
+import org.apache.geode.internal.lang.ObjectUtils;
+import org.apache.geode.internal.lang.StringUtils;
+import org.apache.geode.internal.lang.SystemUtils;
+import org.apache.geode.internal.process.PidUnavailableException;
+import org.apache.geode.internal.process.ProcessUtils;
+import org.apache.geode.internal.util.SunAPINotFoundException;
+import org.apache.geode.management.internal.cli.json.GfJsonObject;
 
 import java.io.*;
 import java.net.BindException;
@@ -46,7 +46,7 @@ import java.util.logging.FileHandler;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 /**
  * The AbstractLauncher class is a base class for implementing various launchers to construct and run different GemFire
@@ -54,7 +54,7 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  * 
  * @see java.lang.Comparable
  * @see java.lang.Runnable
- * @see com.gemstone.gemfire.lang.Identifiable
+ * @see org.apache.geode.lang.Identifiable
  * @since GemFire 7.0
  */
 public abstract class AbstractLauncher<T extends Comparable<T>> implements Runnable {
@@ -120,7 +120,7 @@ public abstract class AbstractLauncher<T extends Comparable<T>> implements Runna
    * @param port an integer indicating the network port to listen for client network requests.
    * @throws BindException if the network address and port are not available.  Address defaults to localhost (or all
    * network interfaces on the local system) if null.
-   * @see com.gemstone.gemfire.internal.AvailablePort
+   * @see org.apache.geode.internal.AvailablePort
    */
   protected static void assertPortAvailable(final InetAddress bindAddress, final int port) throws BindException {
     if (!AvailablePort.isPortAvailable(port, AvailablePort.SOCKET, bindAddress)) {
@@ -714,7 +714,7 @@ public abstract class AbstractLauncher<T extends Comparable<T>> implements Runna
      * Gets the state of the GemFire service.
      * 
      * @return a Status enumerated type representing the state of the GemFire service.
-     * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status
+     * @see org.apache.geode.distributed.AbstractLauncher.Status
      */
     public Status getStatus() {
       return status;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/ClientSocketFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/ClientSocketFactory.java b/geode-core/src/main/java/org/apache/geode/distributed/ClientSocketFactory.java
index 906339a..6a0e30f 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/ClientSocketFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/ClientSocketFactory.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 import java.io.IOException;
 import java.net.InetAddress;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/ConfigurationProperties.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/DistributedLockService.java b/geode-core/src/main/java/org/apache/geode/distributed/DistributedLockService.java
index 0d0fd0c..4ceefaa 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/DistributedLockService.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/DistributedLockService.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.distributed.internal.locks.*;
-import com.gemstone.gemfire.distributed.internal.*;
+import org.apache.geode.distributed.internal.locks.*;
+import org.apache.geode.distributed.internal.*;
 
 /**
  * <p>A named instance of DistributedLockService defines a space for
@@ -351,7 +351,7 @@ public abstract class DistributedLockService {
    * @throws IllegalArgumentException if <code>serviceName<code> does not
    * refer to any registered locking service in this process
    *
-   * @see com.gemstone.gemfire.distributed.DistributedLockService#becomeLockGrantor()
+   * @see org.apache.geode.distributed.DistributedLockService#becomeLockGrantor()
    */
   public static void becomeLockGrantor(String serviceName)
   throws IllegalArgumentException {
@@ -362,7 +362,7 @@ public abstract class DistributedLockService {
    * Returns true if this member is currently the lock authority responsible
    * for granting locks for this service.  This can be explicitly requested by
    * calling {@link 
-   * com.gemstone.gemfire.distributed.DistributedLockService#becomeLockGrantor()}.
+   * org.apache.geode.distributed.DistributedLockService#becomeLockGrantor()}.
    * If no member has explicitly requested grantor authority, then one member 
    * participating in the service will be implicitly selected.  In either case, 
    * this method returns true if the calling member is the grantor.
@@ -383,7 +383,7 @@ public abstract class DistributedLockService {
    * @throws IllegalArgumentException if <code>serviceName<code> does not
    * refer to any registered locking service in this process
    *
-   * @see com.gemstone.gemfire.distributed.DistributedLockService#isLockGrantor()
+   * @see org.apache.geode.distributed.DistributedLockService#isLockGrantor()
    */
   public static boolean isLockGrantor(String serviceName)
   throws IllegalArgumentException {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/DistributedMember.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/DistributedMember.java b/geode-core/src/main/java/org/apache/geode/distributed/DistributedMember.java
index 58c5094..7043bd1 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/DistributedMember.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/DistributedMember.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 import java.util.List;
 import java.util.Set;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystem.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystemDisconnectedException.java b/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystemDisconnectedException.java
index 2858780..dd48cf8 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystemDisconnectedException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystemDisconnectedException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 
 /**
  * Thrown when a GemFire distributed system has been terminated.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/DurableClientAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/DurableClientAttributes.java b/geode-core/src/main/java/org/apache/geode/distributed/DurableClientAttributes.java
index 12276dc..6b55731 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/DurableClientAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/DurableClientAttributes.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.internal.cache.tier.sockets.ClientProxyMembershipID;
+import org.apache.geode.internal.cache.tier.sockets.ClientProxyMembershipID;
 
 /**
  * Class <code>DurableClientAttributes</code> represents durable member

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/FutureCancelledException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/FutureCancelledException.java b/geode-core/src/main/java/org/apache/geode/distributed/FutureCancelledException.java
index 42bb58c..56584c8 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/FutureCancelledException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/FutureCancelledException.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 import java.util.concurrent.Future;
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 
 /**
  * Thrown when a {@link Future} has been cancelled.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/GatewayCancelledException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/GatewayCancelledException.java b/geode-core/src/main/java/org/apache/geode/distributed/GatewayCancelledException.java
index 11d975f..285a40f 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/GatewayCancelledException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/GatewayCancelledException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 
 /**
  * Thrown when a GemFire WAN gateway has been terminated.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/LeaseExpiredException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/LeaseExpiredException.java b/geode-core/src/main/java/org/apache/geode/distributed/LeaseExpiredException.java
index 03271d5..e5da73b 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/LeaseExpiredException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/LeaseExpiredException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * A <code>LeaseExpiredException</code> is thrown when GemFire

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/Locator.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/LockNotHeldException.java b/geode-core/src/main/java/org/apache/geode/distributed/LockNotHeldException.java
index 7a52bee..62b88f1 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/LockNotHeldException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/LockNotHeldException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 /**
  * A <code>LockNotHeldException</code> is thrown when attempting

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/LockServiceDestroyedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/LockServiceDestroyedException.java b/geode-core/src/main/java/org/apache/geode/distributed/LockServiceDestroyedException.java
index db452bb..fd1ec90 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/LockServiceDestroyedException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/LockServiceDestroyedException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 /**
  * A <code>LockServiceDestroyedException</code> is thrown when attempting

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/OplogCancelledException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/OplogCancelledException.java b/geode-core/src/main/java/org/apache/geode/distributed/OplogCancelledException.java
index fa7cb58..92853bb 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/OplogCancelledException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/OplogCancelledException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 
 /**
  * Thrown when a GemFire operation log has been terminated.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/PoolCancelledException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/PoolCancelledException.java b/geode-core/src/main/java/org/apache/geode/distributed/PoolCancelledException.java
index 4cbd994..9c4236a 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/PoolCancelledException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/PoolCancelledException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 
 /**
  * Thrown when a GemFire connection pool has been terminated.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/Role.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/Role.java b/geode-core/src/main/java/org/apache/geode/distributed/Role.java
index f095119..d8440b8 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/Role.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/Role.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 /**
  * Members of the distributed system can fill one or more user defined roles.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncher.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncher.java b/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncher.java
index 20af203..a3d3845 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncher.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncher.java
@@ -15,33 +15,33 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
-
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
-
-import com.gemstone.gemfire.SystemFailure;
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.partition.PartitionRegionHelper;
-import com.gemstone.gemfire.cache.server.CacheServer;
-import com.gemstone.gemfire.distributed.internal.DefaultServerLauncherCacheProvider;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.internal.GemFireVersion;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.cache.*;
-import com.gemstone.gemfire.internal.cache.tier.sockets.CacheServerHelper;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.lang.ObjectUtils;
-import com.gemstone.gemfire.internal.lang.StringUtils;
-import com.gemstone.gemfire.internal.lang.SystemUtils;
-import com.gemstone.gemfire.internal.process.*;
-import com.gemstone.gemfire.internal.util.IOUtils;
-import com.gemstone.gemfire.lang.AttachAPINotFoundException;
-import com.gemstone.gemfire.management.internal.cli.i18n.CliStrings;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonArray;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonException;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonObject;
-import com.gemstone.gemfire.pdx.PdxSerializer;
+package org.apache.geode.distributed;
+
+import static org.apache.geode.distributed.ConfigurationProperties.*;
+
+import org.apache.geode.SystemFailure;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.partition.PartitionRegionHelper;
+import org.apache.geode.cache.server.CacheServer;
+import org.apache.geode.distributed.internal.DefaultServerLauncherCacheProvider;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.internal.GemFireVersion;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.cache.*;
+import org.apache.geode.internal.cache.tier.sockets.CacheServerHelper;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.lang.ObjectUtils;
+import org.apache.geode.internal.lang.StringUtils;
+import org.apache.geode.internal.lang.SystemUtils;
+import org.apache.geode.internal.process.*;
+import org.apache.geode.internal.util.IOUtils;
+import org.apache.geode.lang.AttachAPINotFoundException;
+import org.apache.geode.management.internal.cli.i18n.CliStrings;
+import org.apache.geode.management.internal.cli.json.GfJsonArray;
+import org.apache.geode.management.internal.cli.json.GfJsonException;
+import org.apache.geode.management.internal.cli.json.GfJsonObject;
+import org.apache.geode.pdx.PdxSerializer;
 import joptsimple.OptionException;
 import joptsimple.OptionParser;
 import joptsimple.OptionSet;
@@ -60,14 +60,14 @@ import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.SERVER_BIND_ADDRESS;
+import static org.apache.geode.distributed.ConfigurationProperties.SERVER_BIND_ADDRESS;
 
 /**
  * The ServerLauncher class is a launcher class with main method to start a GemFire Server (implying a GemFire Cache
  * Server process).
  * 
- * @see com.gemstone.gemfire.distributed.AbstractLauncher
- * @see com.gemstone.gemfire.distributed.LocatorLauncher
+ * @see org.apache.geode.distributed.AbstractLauncher
+ * @see org.apache.geode.distributed.LocatorLauncher
  * @since GemFire 7.0
  */
 @SuppressWarnings({ "unused" })
@@ -219,7 +219,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * 
    * @param builder an instance of ServerLauncher.Builder for configuring and constructing an instance of the
    * ServerLauncher.
-   * @see com.gemstone.gemfire.distributed.ServerLauncher.Builder
+   * @see org.apache.geode.distributed.ServerLauncher.Builder
    */
   private ServerLauncher(final Builder builder) {
     this.cache = builder.getCache(); // testing
@@ -276,7 +276,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * Gets a reference to the Cache that was created when the GemFire Server was started.
    * 
    * @return a reference to the Cache created by the GemFire Server start operation.
-   * @see com.gemstone.gemfire.cache.Cache
+   * @see org.apache.geode.cache.Cache
    */
   final Cache getCache() {
     if (this.cache != null) {
@@ -325,7 +325,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * Get the Server launcher command used to invoke the Server.
    * 
    * @return the Server launcher command used to invoke the Server.
-   * @see com.gemstone.gemfire.distributed.ServerLauncher.Command
+   * @see org.apache.geode.distributed.ServerLauncher.Command
    */
   public Command getCommand() {
     return this.command;
@@ -365,7 +365,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * if the user entered the "--help" option (switch) on the command-line.
    * 
    * @return a boolean value indicating if this launcher is used for displaying help information.
-   * @see com.gemstone.gemfire.distributed.ServerLauncher.Command
+   * @see org.apache.geode.distributed.ServerLauncher.Command
    */
   public boolean isHelping() {
     return this.help;
@@ -513,7 +513,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * the GemFire Server on start.
    * <p>
    * @return a String indicating the location of the Spring XML configuration file.
-   * @see com.gemstone.gemfire.distributed.ServerLauncher.Builder#getSpringXmlLocation()
+   * @see org.apache.geode.distributed.ServerLauncher.Builder#getSpringXmlLocation()
    */
   public String getSpringXmlLocation() {
     return this.springXmlLocation;
@@ -606,7 +606,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
   /**
    * Displays usage information on the proper invocation of the ServerLauncher from the command-line to standard err.
    * 
-   * @see #help(com.gemstone.gemfire.distributed.ServerLauncher.Command)
+   * @see #help(org.apache.geode.distributed.ServerLauncher.Command)
    */
   public void usage() {
     info(StringUtils.wrap(helpMap.get("launcher"), 80, "\t"));
@@ -920,7 +920,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * Causes a rebalance operation to occur on the given Cache.
    * 
    * @param cache the reference to the Cache to rebalance.
-   * @see com.gemstone.gemfire.cache.control.ResourceManager#createRebalanceFactory()
+   * @see org.apache.geode.cache.control.ResourceManager#createRebalanceFactory()
    */
   private void rebalance(final Cache cache) {
     if (isRebalancing()) {
@@ -944,7 +944,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * Assigns buckets to individual Partitioned Regions of the Cache.
    * 
    * @param cache the Cache who's Partitioned Regions are accessed to assign buckets to.
-   * @see PartitionRegionHelper#assignBucketsToPartitions(com.gemstone.gemfire.cache.Region)
+   * @see PartitionRegionHelper#assignBucketsToPartitions(org.apache.geode.cache.Region)
    */
   final void assignBuckets(final Cache cache) {
     if (isAssignBucketsAllowed(cache)) {
@@ -1569,7 +1569,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * Iterates the list of arguments in search of the target Server launcher command.
      * 
      * @param args an array of arguments from which to search for the Server launcher command.
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command#valueOfName(String)
+     * @see org.apache.geode.distributed.ServerLauncher.Command#valueOfName(String)
      * @see #parseArguments(String...)
      */
     protected void parseCommand(final String... args) {
@@ -1590,7 +1590,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * for the Server in GemFire.
      * 
      * @param args the array of arguments from which to search for the Server's member name in GemFire.
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command#isCommand(String)
+     * @see org.apache.geode.distributed.ServerLauncher.Command#isCommand(String)
      * @see #parseArguments(String...)
      */
     protected void parseMemberName(final String... args) {
@@ -1617,8 +1617,8 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * Gets the Server launcher command used during the invocation of the ServerLauncher.
      * 
      * @return the Server launcher command used to invoke (run) the ServerLauncher class.
-     * @see #setCommand(com.gemstone.gemfire.distributed.ServerLauncher.Command)
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command
+     * @see #setCommand(org.apache.geode.distributed.ServerLauncher.Command)
+     * @see org.apache.geode.distributed.ServerLauncher.Command
      */
     public Command getCommand() {
       return ObjectUtils.defaultIfNull(this.command, DEFAULT_COMMAND);
@@ -1630,7 +1630,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * @param command the targeted Server launcher command used during the invocation (run) of ServerLauncher.
      * @return this Builder instance.
      * @see #getCommand()
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command
+     * @see org.apache.geode.distributed.ServerLauncher.Command
      */
     public Builder setCommand(final Command command) {
       this.command = command;
@@ -1728,7 +1728,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * Gets the boolean value used by the Server to determine if it should overwrite the PID file if it already exists.
      * 
      * @return the boolean value specifying whether or not to overwrite the PID file if it already exists.
-     * @see com.gemstone.gemfire.internal.process.LocalProcessLauncher
+     * @see org.apache.geode.internal.process.LocalProcessLauncher
      * @see #setForce(Boolean)
      */
     public Boolean getForce() {
@@ -1740,7 +1740,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * 
      * @param force a boolean value indicating whether to overwrite the PID file when it already exists.
      * @return this Builder instance.
-     * @see com.gemstone.gemfire.internal.process.LocalProcessLauncher
+     * @see org.apache.geode.internal.process.LocalProcessLauncher
      * @see #getForce()
      */
     public Builder setForce(final Boolean force) {
@@ -2259,7 +2259,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
     /**
      * Validates the arguments passed to the Builder when the 'start' command has been issued.
      * 
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command#START
+     * @see org.apache.geode.distributed.ServerLauncher.Command#START
      */
     protected void validateOnStart() {
       if (Command.START.equals(getCommand())) {
@@ -2282,7 +2282,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
     /**
      * Validates the arguments passed to the Builder when the 'status' command has been issued.
      * 
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command#STATUS
+     * @see org.apache.geode.distributed.ServerLauncher.Command#STATUS
      */
     protected void validateOnStatus() {
       if (Command.STATUS.equals(getCommand())) {
@@ -2293,7 +2293,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
     /**
      * Validates the arguments passed to the Builder when the 'stop' command has been issued.
      * 
-     * @see com.gemstone.gemfire.distributed.ServerLauncher.Command#STOP
+     * @see org.apache.geode.distributed.ServerLauncher.Command#STOP
      */
     protected void validateOnStop() {
       if (Command.STOP.equals(getCommand())) {
@@ -2307,7 +2307,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
      * 
      * @return a newly constructed instance of the ServerLauncher configured with this Builder.
      * @see #validate()
-     * @see com.gemstone.gemfire.distributed.ServerLauncher
+     * @see org.apache.geode.distributed.ServerLauncher
      */
     public ServerLauncher build() {
       validate();
@@ -2429,7 +2429,7 @@ public class ServerLauncher extends AbstractLauncher<String> {
    * The ServerState is an immutable type representing the state of the specified Locator at any given moment in time.
    * The state of the Locator is assessed at the exact moment an instance of this class is constructed.
    * 
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.ServiceState
+   * @see org.apache.geode.distributed.AbstractLauncher.ServiceState
    */
   public static final class ServerState extends ServiceState<String> {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncherCacheProvider.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncherCacheProvider.java b/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncherCacheProvider.java
index 5dad5fe..014c6da 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncherCacheProvider.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/ServerLauncherCacheProvider.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 import java.util.Properties;
 
-import com.gemstone.gemfire.cache.Cache;
+import org.apache.geode.cache.Cache;
 
 /**
  * ServerLauncherCacheProvider is an extension point for overriding

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/TXManagerCancelledException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/TXManagerCancelledException.java b/geode-core/src/main/java/org/apache/geode/distributed/TXManagerCancelledException.java
index eedefd1..94e2abd 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/TXManagerCancelledException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/TXManagerCancelledException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 
 /**
  * Thrown when a GemFire transaction manager has been terminated.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/AbstractDistributionConfig.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/AbstractDistributionConfig.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/AbstractDistributionConfig.java
index 36f636d..727c5ab 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/AbstractDistributionConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/AbstractDistributionConfig.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 import java.lang.reflect.Method;
 import java.net.InetAddress;
@@ -32,18 +32,18 @@ import java.util.StringTokenizer;
 
 import org.apache.commons.lang.StringUtils;
 
-import com.gemstone.gemfire.InternalGemFireException;
-import com.gemstone.gemfire.InvalidValueException;
-import com.gemstone.gemfire.UnmodifiableException;
-import com.gemstone.gemfire.internal.AbstractConfig;
-import com.gemstone.gemfire.internal.ConfigSource;
-import com.gemstone.gemfire.internal.admin.remote.DistributionLocatorId;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogWriterImpl;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.security.SecurableCommunicationChannel;
-import com.gemstone.gemfire.internal.security.SecurableComponent;
-import com.gemstone.gemfire.memcached.GemFireMemcachedServer;
+import org.apache.geode.InternalGemFireException;
+import org.apache.geode.InvalidValueException;
+import org.apache.geode.UnmodifiableException;
+import org.apache.geode.internal.AbstractConfig;
+import org.apache.geode.internal.ConfigSource;
+import org.apache.geode.internal.admin.remote.DistributionLocatorId;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogWriterImpl;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.security.SecurableCommunicationChannel;
+import org.apache.geode.internal.security.SecurableComponent;
+import org.apache.geode.memcached.GemFireMemcachedServer;
 
 /**
  * Provides an implementation of <code>DistributionConfig</code> that

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/AdminMessageType.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/AdminMessageType.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/AdminMessageType.java
index 57e216f..8563d64 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/AdminMessageType.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/AdminMessageType.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 /**
  * A marker interface that messages related to administation must implement.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/AtomicLongWithTerminalState.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/AtomicLongWithTerminalState.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/AtomicLongWithTerminalState.java
index 85286da..6ef86f1 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/AtomicLongWithTerminalState.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/AtomicLongWithTerminalState.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.util.concurrent.atomic.AtomicLong;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/CacheTime.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/CacheTime.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/CacheTime.java
index 08c1400..25bfac9 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/CacheTime.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/CacheTime.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 /**
  * Provides a method to get the system millisecond clock time

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/CollectingReplyProcessor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/CollectingReplyProcessor.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/CollectingReplyProcessor.java
index 2a7347b..163bf2d 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/CollectingReplyProcessor.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/CollectingReplyProcessor.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.util.Collection;
 import java.util.HashMap;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttribute.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttribute.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttribute.java
index de2573c..f5ce7bc 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttribute.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttribute.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeChecker.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeChecker.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeChecker.java
index 21e130d..5171fde 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeChecker.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeChecker.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeDesc.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeDesc.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeDesc.java
index bc6f017..c8e5769 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeDesc.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeDesc.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeGetter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeGetter.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeGetter.java
index 6e24074..f62dc3c 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeGetter.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeGetter.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeSetter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeSetter.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeSetter.java
index 2cec022..0b9a2cc 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeSetter.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConfigAttributeSetter.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/ConflationKey.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConflationKey.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConflationKey.java
index 5360ebc..35450a1 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/ConflationKey.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/ConflationKey.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.nio.ByteBuffer;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DM.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DM.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DM.java
index a3741a7..327ca37 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DM.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DM.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.io.NotSerializableException;
 import java.net.InetAddress;
@@ -25,13 +25,13 @@ import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.concurrent.ExecutorService;
 
-import com.gemstone.gemfire.CancelCriterion;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.Role;
-import com.gemstone.gemfire.distributed.internal.locks.ElderState;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.distributed.internal.membership.MembershipManager;
-import com.gemstone.gemfire.internal.Version;
+import org.apache.geode.CancelCriterion;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.Role;
+import org.apache.geode.distributed.internal.locks.ElderState;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.distributed.internal.membership.MembershipManager;
+import org.apache.geode.internal.Version;
 
 /**
  * This interface defines the services provided  by any class that

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DMStats.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DMStats.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DMStats.java
index 1a230c7..1c70b6c 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DMStats.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DMStats.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 /**
  * Defines the interface used to access and modify DM statistics.
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/ConfigurationProperties.java b/geode-core/src/main/java/org/apache/geode/distributed/ConfigurationProperties.java
index c919a64..d843792 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/ConfigurationProperties.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/ConfigurationProperties.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 import org.apache.geode.redis.GeodeRedisServer;
 import org.apache.geode.security.SecurableComponents;
@@ -141,7 +141,7 @@ public interface ConfigurationProperties {
    * <a name="cache-xml-file"/a></p>
    * <U>Description</U>: Specifies the name of the XML file or resource
    * to initialize the cache with when it is
-   * {@linkplain com.gemstone.gemfire.cache.CacheFactory#create created}.
+   * {@linkplain org.apache.geode.cache.CacheFactory#create created}.
    * Create will first look for a file that matches the value of this property.
    * If a file is not found then it will be searched for using
    * {@link java.lang.ClassLoader#getResource}.  If the value of this
@@ -311,7 +311,7 @@ public interface ConfigurationProperties {
    * <dt>delta-propagation</dt>
    * </a>
    * <U>Description</U>: "true" indicates that server propagates delta
-   * generated from {@link com.gemstone.gemfire.Delta} type of objects. If "false"
+   * generated from {@link org.apache.geode.Delta} type of objects. If "false"
    * then server propagates full object but not delta. </p>
    * <U>Default</U>: "true"</p>
    * <U>Allowed values</U>: true|false
@@ -1177,16 +1177,16 @@ public interface ConfigurationProperties {
   /**
    * The static String definition of the <i>"memcached-bind-address"</i> property
    * <a name="memcached-bind-address"/a></p>
    * <U>Description</U>: Specifies the bind address used by {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer}</p>
    * <U>Default</U>: ""
    */
   String MEMCACHED_BIND_ADDRESS = "memcached-bind-address";
   /**
    * The static String definition of the <i>"memcached-port"</i> property
    * <a name="memcached-port"/a></p>
-   * <U>Description</U>: Specifies the port used by {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer}
+   * <U>Description</U>: Specifies the port used by {@link org.apache.geode.memcached.GemFireMemcachedServer}
    * which enables memcached clients to connect and store data in GemFire distributed system.
    * see {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer} for other configuration options.</p>
    * <U>Default</U>: "0" disables GemFireMemcachedServer</p>
    * <U>Allowed values</U>: 0..65535
    */
@@ -1194,7 +1194,7 @@ public interface ConfigurationProperties {
   /**
    * The static String definition of the <i>"memcached-protocol"</i> property
    * <a name="memcached-protocol"/a></p>
    * <U>Description</U>: Specifies the protocol used by {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer}</p>
    * <U>Default</U>: "ASCII"</p>
    * <U>Allowed values</U>: "ASCII" "BINARY"
    */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/DistributedLockService.java
----------------------------------------------------------------------
@@ -1177,16 +1177,16 @@ public interface ConfigurationProperties {
    * The static String definition of the <i>"memcached-bind-address"</i> property
    * <a name="memcached-bind-address"/a></p>
-   * <U>Description</U>: Specifies the bind address used by {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer}</p>
+   * <U>Description</U>: Specifies the bind address used by {@link org.apache.geode.memcached.GemFireMemcachedServer}</p>
    * <U>Default</U>: ""
    */
@@ -1177,16 +1177,16 @@ public interface ConfigurationProperties {
    * which enables memcached clients to connect and store data in GemFire distributed system.
-   * see {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer} for other configuration options.</p>
+   * see {@link org.apache.geode.memcached.GemFireMemcachedServer} for other configuration options.</p>
    * <U>Default</U>: "0" disables GemFireMemcachedServer</p>
    * <U>Allowed values</U>: 0..65535
@@ -1194,7 +1194,7 @@ public interface ConfigurationProperties {
    * The static String definition of the <i>"memcached-protocol"</i> property
    * <a name="memcached-protocol"/a></p>
-   * <U>Description</U>: Specifies the protocol used by {@link com.gemstone.gemfire.memcached.GemFireMemcachedServer}</p>
+   * <U>Description</U>: Specifies the protocol used by {@link org.apache.geode.memcached.GemFireMemcachedServer}</p>
    * <U>Default</U>: "ASCII"</p>
    * <U>Allowed values</U>: "ASCII" "BINARY"
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystem.java b/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystem.java
index 75fb39f..d0c7366 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystem.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystem.java
@@ -15,24 +15,24 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
-
-import com.gemstone.gemfire.CancelCriterion;
-import com.gemstone.gemfire.LogWriter;
-import com.gemstone.gemfire.StatisticsFactory;
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.CacheFactory;
-import com.gemstone.gemfire.cache.client.ClientCache;
-import com.gemstone.gemfire.cache.client.ClientCacheFactory;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.DistributionManager;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.ClassPathLoader;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.tcp.ConnectionTable;
-import com.gemstone.gemfire.internal.util.IOUtils;
-import com.gemstone.gemfire.security.GemFireSecurityException;
+package org.apache.geode.distributed;
+
+import org.apache.geode.CancelCriterion;
+import org.apache.geode.LogWriter;
+import org.apache.geode.StatisticsFactory;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.CacheFactory;
+import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.client.ClientCacheFactory;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.DistributionManager;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.ClassPathLoader;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.tcp.ConnectionTable;
+import org.apache.geode.internal.util.IOUtils;
+import org.apache.geode.security.GemFireSecurityException;
 
 import java.io.File;
 import java.net.InetAddress;
@@ -41,7 +41,7 @@ import java.net.URL;
 import java.util.*;
 import java.util.concurrent.TimeUnit;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 /**
  * A "connection" to a GemFire distributed system.  A
@@ -49,9 +49,9 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  * #connect} method with a configuration as described <a
  * href="#configuration">below</a>.  A <code>DistributedSystem</code>
  * is used when calling {@link
  * com.gemstone.gemfire.cache.CacheFactory#create}.  This class should
  * not be confused with the {@link
- * com.gemstone.gemfire.admin.AdminDistributedSystem
+ * org.apache.geode.admin.AdminDistributedSystem
  * AdminDistributedSystem} interface that is used for administering a
  * distributed system.
  *
@@ -169,12 +169,12 @@ public abstract class DistributedSystem implements StatisticsFactory {
    *         If a <code>DistributedSystem</code> with a different
    *         configuration has already been created in this VM or if
    *         this VM is {@link
-   *         com.gemstone.gemfire.admin.AdminDistributedSystem
+   *         org.apache.geode.admin.AdminDistributedSystem
    *         administering} a distributed system.
-   * @throws com.gemstone.gemfire.GemFireIOException
+   * @throws org.apache.geode.GemFireIOException
    *         Problems while reading configuration properties file or
    *         while opening the log file.
-   * @throws com.gemstone.gemfire.GemFireConfigException
+   * @throws org.apache.geode.GemFireConfigException
    *         The distribution transport is not configured correctly
    *
    * @deprecated as of 6.5 use {@link CacheFactory#create} or {@link ClientCacheFactory#create} instead.
@@ -349,7 +349,7 @@ public abstract class DistributedSystem implements StatisticsFactory {
   }
 
   /**
-   * see {@link com.gemstone.gemfire.admin.AdminDistributedSystemFactory}
+   * see {@link org.apache.geode.admin.AdminDistributedSystemFactory}
    * @since GemFire 5.7
    */
   protected static void setEnableAdministrationOnly(boolean adminOnly) {
@@ -372,11 +372,11 @@ public abstract class DistributedSystem implements StatisticsFactory {
 //    *        used when connecting to the distributed system
 //    * @param callback
 //    *        A user-specified object that is delivered with the {@link
-//    *        com.gemstone.gemfire.admin.SystemMembershipEvent}
+//    *        org.apache.geode.admin.SystemMembershipEvent}
 //    *        triggered by connecting.
 //    *
 //    * @see #connect(Properties)
-//    * @see com.gemstone.gemfire.admin.SystemMembershipListener#memberJoined
+//    * @see org.apache.geode.admin.SystemMembershipListener#memberJoined
 //    *
 //    * @since GemFire 4.0
 //    */
@@ -441,7 +441,7 @@ public abstract class DistributedSystem implements StatisticsFactory {
   /**
    * Disconnects from this distributed system.  This operation will
    * close the distribution manager and render the {@link
-   * com.gemstone.gemfire.cache.Cache Cache} and all distributed
+   * org.apache.geode.cache.Cache Cache} and all distributed
    * collections obtained from this distributed system inoperable.
    * After a disconnect has completed, a VM may connect to another
    * distributed system.
@@ -476,7 +476,7 @@ public abstract class DistributedSystem implements StatisticsFactory {
    * Returns a string that uniquely identifies this connection to the
    * distributed system.
    *
-   * @see com.gemstone.gemfire.admin.SystemMembershipEvent#getMemberId
+   * @see org.apache.geode.admin.SystemMembershipEvent#getMemberId
    *
    * @since GemFire 4.0
    * @deprecated as of GemFire 5.0, use {@link #getDistributedMember} instead

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/DistributedSystemDisconnectedException.java
----------------------------------------------------------------------
@@ -49,9 +49,9 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  * href="#configuration">below</a>.  A <code>DistributedSystem</code>
  * is used when calling {@link
- * com.gemstone.gemfire.cache.CacheFactory#create}.  This class should
+ * org.apache.geode.cache.CacheFactory#create}.  This class should
  * not be confused with the {@link
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/Locator.java b/geode-core/src/main/java/org/apache/geode/distributed/Locator.java
index 055ef27..1b2f06e 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/Locator.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/Locator.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed;
+package org.apache.geode.distributed;
 
 import java.io.File;
 import java.io.IOException;
@@ -23,9 +23,9 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Properties;
 
-import com.gemstone.gemfire.distributed.internal.InternalLocator;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.distributed.internal.InternalLocator;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * Represents a distribution locator server that provides discovery information
@@ -105,10 +105,10 @@ public abstract class Locator {
    *
    * @throws IllegalArgumentException
    *         If <code>port</code> is not in the range 0 to 65536
-   * @throws com.gemstone.gemfire.SystemIsRunningException
+   * @throws org.apache.geode.SystemIsRunningException
    *         If another locator is already running in
    *         <code>outputDir</code>
-   * @throws com.gemstone.gemfire.GemFireIOException
+   * @throws org.apache.geode.GemFireIOException
    *         If the directory containing the <code>logFile</code> does
    *         not exist or cannot be written to
    * @throws IOException
@@ -151,10 +151,10 @@ public abstract class Locator {
    * 
    * @throws IllegalArgumentException
    *                 If <code>port</code> is not in the range 0 to 65536
-   * @throws com.gemstone.gemfire.SystemIsRunningException
+   * @throws org.apache.geode.SystemIsRunningException
    *                 If another locator is already running in
    *                 <code>outputDir</code>
-   * @throws com.gemstone.gemfire.GemFireIOException
+   * @throws org.apache.geode.GemFireIOException
    *                 If the directory containing the <code>logFile</code> does
    *                 not exist or cannot be written to
    * @throws IOException
@@ -186,10 +186,10 @@ public abstract class Locator {
    *
    * @throws IllegalArgumentException
    *         If <code>port</code> is not in the range 0 to 65536
-   * @throws com.gemstone.gemfire.SystemIsRunningException
+   * @throws org.apache.geode.SystemIsRunningException
    *         If another locator is already running in
    *         <code>outputDir</code>
-   * @throws com.gemstone.gemfire.GemFireIOException
+   * @throws org.apache.geode.GemFireIOException
    *         If the directory containing the <code>logFile</code> does
    *         not exist or cannot be written to
    * @throws IOException
@@ -233,10 +233,10 @@ public abstract class Locator {
    *
    * @throws IllegalArgumentException
    *         If <code>port</code> is not in the range 0 to 65536
-   * @throws com.gemstone.gemfire.SystemIsRunningException
+   * @throws org.apache.geode.SystemIsRunningException
    *         If another locator is already running in
    *         <code>outputDir</code>
-   * @throws com.gemstone.gemfire.GemFireIOException
+   * @throws org.apache.geode.GemFireIOException
    *         If the directory containing the <code>logFile</code> does
    *         not exist or cannot be written to
    * @throws IOException
@@ -292,10 +292,10 @@ public abstract class Locator {
    *         If <code>port</code> is not in the range 0 to 65536
    *         or <code>peerLocator</code> and <code> serverLocator</code>
    *         are both false.
-   * @throws com.gemstone.gemfire.SystemIsRunningException
+   * @throws org.apache.geode.SystemIsRunningException
    *         If another locator is already running in
    *         <code>outputDir</code>
-   * @throws com.gemstone.gemfire.GemFireIOException
+   * @throws org.apache.geode.GemFireIOException
    *         If the directory containing the <code>logFile</code> does
    *         not exist or cannot be written to
    * @throws IOException
@@ -511,7 +511,7 @@ public abstract class Locator {
    * The <i>gemfire stop-locator</i> command can be used to stop
    * a locator that is started with this class.
    * <p>
    * java com.gemstone.gemfire.distributed.Locator port [bind-address] [gemfire-properties-file] [peer] [server]
    * <p>
    * port - the tcp/ip port that the locator should listen on.  This is the
    * port number that applications will refer to in their <i>locators</i> property
@@ -539,7 +539,7 @@ public abstract class Locator {
    * @since GemFire 5.0
    */
   public static void main(String args[]) {
-    com.gemstone.gemfire.internal.DistributionLocator.main(args);
+    org.apache.geode.internal.DistributionLocator.main(args);
   }
 
 }

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/LocatorLauncher.java
----------------------------------------------------------------------
@@ -511,7 +511,7 @@ public abstract class Locator {
    * a locator that is started with this class.
    * <p>
-   * java com.gemstone.gemfire.distributed.Locator port [bind-address] [gemfire-properties-file] [peer] [server]
+   * java org.apache.geode.distributed.Locator port [bind-address] [gemfire-properties-file] [peer] [server]
    * <p>
    * port - the tcp/ip port that the locator should listen on.  This is the
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/LocatorLauncher.java b/geode-core/src/main/java/org/apache/geode/distributed/LocatorLauncher.java
index 2f16c59..5db332e 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/LocatorLauncher.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/LocatorLauncher.java
@@ -15,28 +15,28 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed;
-
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
-
-import com.gemstone.gemfire.cache.client.internal.locator.*;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.DistributionConfigImpl;
-import com.gemstone.gemfire.distributed.internal.InternalLocator;
-import com.gemstone.gemfire.distributed.internal.tcpserver.*;
-import com.gemstone.gemfire.internal.DistributionLocator;
-import com.gemstone.gemfire.internal.GemFireVersion;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.lang.ObjectUtils;
-import com.gemstone.gemfire.internal.lang.StringUtils;
-import com.gemstone.gemfire.internal.lang.SystemUtils;
-import com.gemstone.gemfire.internal.process.*;
-import com.gemstone.gemfire.internal.util.IOUtils;
-import com.gemstone.gemfire.lang.AttachAPINotFoundException;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonArray;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonException;
-import com.gemstone.gemfire.management.internal.cli.json.GfJsonObject;
+package org.apache.geode.distributed;
+
+import static org.apache.geode.distributed.ConfigurationProperties.*;
+
+import org.apache.geode.cache.client.internal.locator.*;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.DistributionConfigImpl;
+import org.apache.geode.distributed.internal.InternalLocator;
+import org.apache.geode.distributed.internal.tcpserver.*;
+import org.apache.geode.internal.DistributionLocator;
+import org.apache.geode.internal.GemFireVersion;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.lang.ObjectUtils;
+import org.apache.geode.internal.lang.StringUtils;
+import org.apache.geode.internal.lang.SystemUtils;
+import org.apache.geode.internal.process.*;
+import org.apache.geode.internal.util.IOUtils;
+import org.apache.geode.lang.AttachAPINotFoundException;
+import org.apache.geode.management.internal.cli.json.GfJsonArray;
+import org.apache.geode.management.internal.cli.json.GfJsonException;
+import org.apache.geode.management.internal.cli.json.GfJsonObject;
 import joptsimple.OptionException;
 import joptsimple.OptionParser;
 import joptsimple.OptionSet;
@@ -60,8 +60,8 @@ import java.util.logging.Level;
 /**
  * The LocatorLauncher class is a launcher for a GemFire Locator.
  * 
- * @see com.gemstone.gemfire.distributed.AbstractLauncher
- * @see com.gemstone.gemfire.distributed.ServerLauncher
+ * @see org.apache.geode.distributed.AbstractLauncher
+ * @see org.apache.geode.distributed.ServerLauncher
  * @since GemFire 7.0
  */
 @SuppressWarnings({ "unused" })
@@ -208,7 +208,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * 
    * @param builder an instance of LocatorLauncher.Builder for configuring and constructing an instance of the
    * LocatorLauncher.
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.Builder
+   * @see org.apache.geode.distributed.LocatorLauncher.Builder
    */
   private LocatorLauncher(final Builder builder) {
     this.command = builder.getCommand();
@@ -283,7 +283,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * Get the Locator launcher command used to invoke the Locator.
    * 
    * @return the Locator launcher command used to invoke the Locator.
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command
+   * @see org.apache.geode.distributed.LocatorLauncher.Command
    */
   public Command getCommand() {
     return this.command;
@@ -305,7 +305,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * if the user entered the "--help" option (switch) on the command-line.
    * 
    * @return a boolean value indicating if this launcher is used for displaying help information.
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command
+   * @see org.apache.geode.distributed.LocatorLauncher.Command
    */
   public boolean isHelping() {
     return this.help;
@@ -484,7 +484,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
   /**
    * Displays usage information on the proper invocation of the LocatorLauncher from the command-line to standard err.
    * 
-   * @see #help(com.gemstone.gemfire.distributed.LocatorLauncher.Command)
+   * @see #help(org.apache.geode.distributed.LocatorLauncher.Command)
    */
   public void usage() {
     info(StringUtils.wrap(helpMap.get("launcher"), 80, "\t"));
@@ -508,7 +508,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @see LocatorLauncher#status()
    * @see LocatorLauncher#stop()
    * @see LocatorLauncher#version()
-   * @see LocatorLauncher#help(com.gemstone.gemfire.distributed.LocatorLauncher.Command)
+   * @see LocatorLauncher#help(org.apache.geode.distributed.LocatorLauncher.Command)
    * @see LocatorLauncher#usage()
    */
   public void run() {
@@ -585,10 +585,10 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @see #stop()
    * @see #waitOnLocator()
    * @see #waitOnStatusResponse(long, long, java.util.concurrent.TimeUnit)
    * @see com.gemstone.gemfire.distributed.LocatorLauncher.LocatorState
    * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#NOT_RESPONDING
    * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#ONLINE
    * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#STARTING
    */
   @SuppressWarnings("deprecation")
   public LocatorState start() {
@@ -700,8 +700,8 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @throws AssertionError if the Locator has not been started and the reference is null (assertions must be enabled
    * for the error to be thrown).
    * @see #failOnStart(Throwable)
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.LocatorState
+   * @see org.apache.geode.distributed.AbstractLauncher.Status
+   * @see org.apache.geode.distributed.LocatorLauncher.LocatorState
    */
   public LocatorState waitOnLocator() {
     Throwable t = null;
@@ -804,8 +804,8 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @return the Locator's state.
    * @see #start()
    * @see #stop()
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.LocatorState
+   * @see org.apache.geode.distributed.AbstractLauncher.Status
+   * @see org.apache.geode.distributed.LocatorLauncher.LocatorState
    */
   public LocatorState status() {
     final LocatorLauncher launcher = getInstance();
@@ -970,9 +970,9 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @return a LocatorState indicating the state of the Locator after stop has been requested.
    * @see #start()
    * @see #status()
    * @see com.gemstone.gemfire.distributed.LocatorLauncher.LocatorState
    * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#NOT_RESPONDING
    * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#STOPPED
    */
   public LocatorState stop() {
     final LocatorLauncher launcher = getInstance();
@@ -1303,7 +1303,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
      * Iterates the list of arguments in search of the target Locator launcher command.
      * 
      * @param args an array of arguments from which to search for the Locator launcher command.
-     * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command#valueOfName(String)
+     * @see org.apache.geode.distributed.LocatorLauncher.Command#valueOfName(String)
      * @see #parseArguments(String...)
      */
     protected void parseCommand(final String... args) {
@@ -1324,7 +1324,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
      * for the Locator in GemFire.
      * 
      * @param args the array of arguments from which to search for the Locator's member name in GemFire.
-     * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command#isCommand(String)
+     * @see org.apache.geode.distributed.LocatorLauncher.Command#isCommand(String)
      * @see #parseArguments(String...)
      */
     protected void parseMemberName(final String[] args) {
@@ -1340,7 +1340,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
      * Gets the Locator launcher command used during the invocation of the LocatorLauncher.
      * 
      * @return the Locator launcher command used to invoke (run) the LocatorLauncher class.
-     * @see #setCommand(com.gemstone.gemfire.distributed.LocatorLauncher.Command)
+     * @see #setCommand(org.apache.geode.distributed.LocatorLauncher.Command)
      * @see LocatorLauncher.Command
      */
     public Command getCommand() {
@@ -1396,7 +1396,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
      * Gets the boolean value used by the Locator to determine if it should overwrite the PID file if it already exists.
      * 
      * @return the boolean value specifying whether or not to overwrite the PID file if it already exists.
-     * @see com.gemstone.gemfire.internal.process.LocalProcessLauncher
+     * @see org.apache.geode.internal.process.LocalProcessLauncher
      * @see #setForce(Boolean)
      */
     public Boolean getForce() {
@@ -1408,7 +1408,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
      * 
      * @param force a boolean value indicating whether to overwrite the PID file when it already exists.
      * @return this Builder instance.
-     * @see com.gemstone.gemfire.internal.process.LocalProcessLauncher
+     * @see org.apache.geode.internal.process.LocalProcessLauncher
      * @see #getForce()
      */
     public Builder setForce(final Boolean force) {
@@ -1725,7 +1725,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
     /**
      * Validates the arguments passed to the Builder when the 'start' command has been issued.
      * 
-     * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command#START
+     * @see org.apache.geode.distributed.LocatorLauncher.Command#START
      */
     protected void validateOnStart() {
       if (Command.START.equals(getCommand())) {
@@ -1748,7 +1748,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
     /**
      * Validates the arguments passed to the Builder when the 'status' command has been issued.
      * 
-     * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command#STATUS
+     * @see org.apache.geode.distributed.LocatorLauncher.Command#STATUS
      */
     protected void validateOnStatus() {
       if (Command.STATUS.equals(getCommand())) {
@@ -1758,7 +1758,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
     /**
      * Validates the arguments passed to the Builder when the 'stop' command has been issued.
      * 
-     * @see com.gemstone.gemfire.distributed.LocatorLauncher.Command#STOP
+     * @see org.apache.geode.distributed.LocatorLauncher.Command#STOP
      */
     protected void validateOnStop() {
       if (Command.STOP.equals(getCommand())) {
@@ -1771,7 +1771,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
      * 
      * @return a newly constructed instance of LocatorLauncher configured with this Builder.
      * @see #validate()
-     * @see com.gemstone.gemfire.distributed.LocatorLauncher
+     * @see org.apache.geode.distributed.LocatorLauncher
      */
     public LocatorLauncher build() {
       validate();
@@ -1893,7 +1893,7 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * The LocatorState is an immutable type representing the state of the specified Locator at any given moment in time.
    * The state of the Locator is assessed at the exact moment an instance of this class is constructed.
    * 
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.ServiceState
+   * @see org.apache.geode.distributed.AbstractLauncher.ServiceState
    */
   public static final class LocatorState extends ServiceState<String> {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/LockNotHeldException.java
----------------------------------------------------------------------
@@ -585,10 +585,10 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @see #waitOnLocator()
    * @see #waitOnStatusResponse(long, long, java.util.concurrent.TimeUnit)
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.LocatorState
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#NOT_RESPONDING
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#ONLINE
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#STARTING
+   * @see org.apache.geode.distributed.LocatorLauncher.LocatorState
+   * @see org.apache.geode.distributed.AbstractLauncher.Status#NOT_RESPONDING
+   * @see org.apache.geode.distributed.AbstractLauncher.Status#ONLINE
+   * @see org.apache.geode.distributed.AbstractLauncher.Status#STARTING
    */
   @SuppressWarnings("deprecation")
@@ -970,9 +970,9 @@ public final class LocatorLauncher extends AbstractLauncher<String> {
    * @see #start()
    * @see #status()
-   * @see com.gemstone.gemfire.distributed.LocatorLauncher.LocatorState
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#NOT_RESPONDING
-   * @see com.gemstone.gemfire.distributed.AbstractLauncher.Status#STOPPED
+   * @see org.apache.geode.distributed.LocatorLauncher.LocatorState
+   * @see org.apache.geode.distributed.AbstractLauncher.Status#NOT_RESPONDING
+   * @see org.apache.geode.distributed.AbstractLauncher.Status#STOPPED
    */
   public LocatorState stop() {